@@ -4,13 +4,7 @@ import tempfile
 import cppyy
 
 BUILD_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "c_build"))
-if not os.path.exists(BUILD_DIR) or not os.path.isdir(BUILD_DIR):
-    BUILD_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "../../../../build"))
-
 C_HEADER = os.path.join(os.path.dirname(__file__), "c_includes")
-if not os.path.exists(C_HEADER) or not os.path.isdir(C_HEADER):
-    C_HEADER = os.path.join(os.path.dirname(__file__), "../../../grammar")
-
 C_SHARED_LIB = os.path.join(BUILD_DIR, "dice.so")
 
 
